pyrestsdk.requestbuilder package — PyRESTSDK documentation

# pyrestsdk.requestbuilder package

## Module contents

Request Builder

class pyrestsdk.requestbuilder.BaseRequestBuilder(request_url: str, client: S)

  Bases: `AbstractRequestBuilder`

  Base Request Builder Type

  property Client: S

    Gets/Sets the Client

  append_segment_to_request_url(url_segment: str) → str

    Gets a URL that is the request builder’s request URL with the segment appended.

    Args:

      url_segment (str): The segment to append to the request URL.

    Returns:

      str: A URL that is the request builder’s request URL with the segment appended.

  property request_url: str

    Gets/Sets the request URL

    Returns:

      str: The request URL

class pyrestsdk.requestbuilder.EntityRequestBuilder(request_url: str, client: S)

  Bases: `BaseRequestBuilder`

  Entity Request Builder Type

  abstract Request(options: Iterable[O] | None) → R

    Gets request

  abstract property request: R

    Gets request with no options